#!/usr/bin/env python

"""
Gather all information about the software
"""

NAME = "Vitalus"
URL = "https://github.com/sciunto/Vitalus"
LICENSE = "GPLv3+"
EMAIL = "fboulogne@sciunto.org"
VERSION = "0.3.4"

SHORT_DESCRIPTION = "Rsync wrapper for backups"

AUHTORS = ["Francois Boulogne <fboulogne@sciunto.org>"]

